@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use parent 'Module::Build';
 
@@ -177,8 +177,16 @@ sub new {
   $self->alien_helper->{pkg_config} = 'Alien::Base::PkgConfig->pkg_config_command'
     unless defined $self->alien_helper->{pkg_config};
 
+  my $ab_version = eval {
+    require Alien::Base;
+    Alien::Base->VERSION;
+  };
+  $ab_version ||= 0;
+
   # setup additional temporary directories, and yes we have to add File::ShareDir manually
-  $self->_add_prereq( 'requires', 'File::ShareDir', '1.00' );
+  if($ab_version < 0.77) {
+    $self->_add_prereq( 'requires', 'File::ShareDir', '1.00' );
+  }
 
   # this just gets passed from the Build.PL to the config so that it can
   # be used by the auto_include method
@@ -735,8 +743,11 @@ sub _alien_bin_require {
   
   my $version = $self->alien_bin_requires->{$mod};
 
-  eval qq{ use $mod $version () }; # should also work for version = 0
-  die $@ if $@;
+  unless(eval { $mod->can('new') })
+  {
+    eval '# line '. __LINE__ . ' "' . __FILE__ . qq{\n use $mod $version () }; # should also work for version = 0
+    die $@ if $@;
+  }
   
   if($mod->can('alien_helper')) {
     my $helpers = $mod->alien_helper;
