@@ -3,12 +3,12 @@ package Alien::Base::ModuleBuild::Repository::Local;
 use strict;
 use warnings;
 
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use Carp;
 use File::chdir;
 use File::Copy qw/copy/;
-use File::Spec;
+use Path::Tiny qw( path );
 
 use parent 'Alien::Base::ModuleBuild::Repository';
 
@@ -44,7 +44,7 @@ sub get_file  {
   my $full_file = do {
     local $CWD = $self->location;
     croak "Cannot find file: $file" unless -e $file;
-    File::Spec->rel2abs($file);
+    path($file)->absolute->stringify;
   };
 
   copy $full_file, $CWD;
