@@ -3,12 +3,11 @@ package Alien::Base::PkgConfig;
 use strict;
 use warnings;
 
-our $VERSION = '0.043';
+our $VERSION = '0.044';
 
 use Carp;
 use Config;
-use File::Basename qw/fileparse/;
-use File::Spec;
+use Path::Tiny qw( path );
 use Capture::Tiny qw( capture_stderr );
 
 sub new {
@@ -22,16 +21,13 @@ sub new {
   my ($path) = @_;
   croak "Must specify a file" unless defined $path;
 
-  $path = File::Spec->rel2abs( $path );
+  $path = path( $path )->absolute;
 
-  my ($name, $dir) = fileparse $path, '.pc';
-
-  $dir = File::Spec->catdir( $dir );  # remove trailing slash
-  $dir =~ s{\\}{/}g;
+  my($name) = $path->basename =~ /^(.*)\.pc$/;
 
   my $self = {
     package  => $name,
-    vars     => { pcfiledir => $dir },
+    vars     => { pcfiledir => $path->parent->stringify },
     keywords => {},
   };
 
